@@ -140,7 +140,7 @@ Out of the box implementation of the Construct without any override will set the
 ---
 
 
-© Copyright 2022 Amazon.com, Inc. or its affiliates. All Rights Reserved.
+© Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 '''
 import abc
 import builtins
@@ -156,50 +156,50 @@ from typeguard import check_type
 
 from ._jsii import *
 
-import aws_cdk.aws_ec2
-import aws_cdk.aws_ecs
-import aws_cdk.aws_kms
-import aws_cdk.aws_sqs
-import constructs
+import aws_cdk.aws_ec2 as _aws_cdk_aws_ec2_ceddda9d
+import aws_cdk.aws_ecs as _aws_cdk_aws_ecs_ceddda9d
+import aws_cdk.aws_kms as _aws_cdk_aws_kms_ceddda9d
+import aws_cdk.aws_sqs as _aws_cdk_aws_sqs_ceddda9d
+import constructs as _constructs_77d1e7e8
 
 
 class FargateToSqs(
-    constructs.Construct,
+    _constructs_77d1e7e8.Construct,
     metaclass=jsii.JSIIMeta,
     jsii_type="@aws-solutions-constructs/aws-fargate-sqs.FargateToSqs",
 ):
     def __init__(
         self,
-        scope: constructs.Construct,
+        scope: _constructs_77d1e7e8.Construct,
         id: builtins.str,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param cluster_props: Optional properties to create a new ECS cluster.
         :param container_definition_props: -
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
@@ -223,35 +223,7 @@ class FargateToSqs(
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
         if __debug__:
-            def stub(
-                scope: constructs.Construct,
-                id: builtins.str,
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__1ba793faae145910b2917cda14247795539c6dff02cf4650e68799b90571b95f)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = FargateToSqsProps(
@@ -283,28 +255,30 @@ class FargateToSqs(
 
     @builtins.property
     @jsii.member(jsii_name="container")
-    def container(self) -> aws_cdk.aws_ecs.ContainerDefinition:
-        return typing.cast(aws_cdk.aws_ecs.ContainerDefinition, jsii.get(self, "container"))
+    def container(self) -> _aws_cdk_aws_ecs_ceddda9d.ContainerDefinition:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition, jsii.get(self, "container"))
 
     @builtins.property
     @jsii.member(jsii_name="service")
-    def service(self) -> aws_cdk.aws_ecs.FargateService:
-        return typing.cast(aws_cdk.aws_ecs.FargateService, jsii.get(self, "service"))
+    def service(self) -> _aws_cdk_aws_ecs_ceddda9d.FargateService:
+        return typing.cast(_aws_cdk_aws_ecs_ceddda9d.FargateService, jsii.get(self, "service"))
 
     @builtins.property
     @jsii.member(jsii_name="sqsQueue")
-    def sqs_queue(self) -> aws_cdk.aws_sqs.Queue:
-        return typing.cast(aws_cdk.aws_sqs.Queue, jsii.get(self, "sqsQueue"))
+    def sqs_queue(self) -> _aws_cdk_aws_sqs_ceddda9d.Queue:
+        return typing.cast(_aws_cdk_aws_sqs_ceddda9d.Queue, jsii.get(self, "sqsQueue"))
 
     @builtins.property
     @jsii.member(jsii_name="vpc")
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        return typing.cast(aws_cdk.aws_ec2.IVpc, jsii.get(self, "vpc"))
+    def vpc(self) -> _aws_cdk_aws_ec2_ceddda9d.IVpc:
+        return typing.cast(_aws_cdk_aws_ec2_ceddda9d.IVpc, jsii.get(self, "vpc"))
 
     @builtins.property
     @jsii.member(jsii_name="deadLetterQueue")
-    def dead_letter_queue(self) -> typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue]:
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
+    def dead_letter_queue(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue]:
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.DeadLetterQueue], jsii.get(self, "deadLetterQueue"))
 
 
 @jsii.data_type(
@@ -340,30 +314,30 @@ class FargateToSqsProps:
         self,
         *,
         public_api: builtins.bool,
-        cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
+        cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
         container_definition_props: typing.Any = None,
-        dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
         ecr_image_version: typing.Optional[builtins.str] = None,
         ecr_repository_arn: typing.Optional[builtins.str] = None,
         enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-        encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-        encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-        existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-        existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-        existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-        existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
+        encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+        encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+        existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+        existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+        existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+        existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
         fargate_service_props: typing.Any = None,
         fargate_task_definition_props: typing.Any = None,
         max_receive_count: typing.Optional[jsii.Number] = None,
         queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
         queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-        queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
+        queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
         queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-        vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
+        vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
     ) -> None:
         '''
-        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct. Default: - none
+        :param public_api: Whether the construct is deploying a private or public API. This has implications for the VPC deployed by this construct.
         :param cluster_props: Optional properties to create a new ECS cluster.
         :param container_definition_props: -
         :param dead_letter_queue_props: Optional user provided properties for the dead letter queue. Default: - Default props are used
@@ -387,43 +361,17 @@ class FargateToSqsProps:
         :param vpc_props: Optional custom properties for a VPC the construct will create. This VPC will be used by the new Fargate service the construct creates (that's why targetGroupProps can't include a VPC). Providing both this and existingVpc is an error. An SQS Interface endpoint will be included in this VPC. Default: - none
         '''
         if isinstance(cluster_props, dict):
-            cluster_props = aws_cdk.aws_ecs.ClusterProps(**cluster_props)
+            cluster_props = _aws_cdk_aws_ecs_ceddda9d.ClusterProps(**cluster_props)
         if isinstance(dead_letter_queue_props, dict):
-            dead_letter_queue_props = aws_cdk.aws_sqs.QueueProps(**dead_letter_queue_props)
+            dead_letter_queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**dead_letter_queue_props)
         if isinstance(encryption_key_props, dict):
-            encryption_key_props = aws_cdk.aws_kms.KeyProps(**encryption_key_props)
+            encryption_key_props = _aws_cdk_aws_kms_ceddda9d.KeyProps(**encryption_key_props)
         if isinstance(queue_props, dict):
-            queue_props = aws_cdk.aws_sqs.QueueProps(**queue_props)
+            queue_props = _aws_cdk_aws_sqs_ceddda9d.QueueProps(**queue_props)
         if isinstance(vpc_props, dict):
-            vpc_props = aws_cdk.aws_ec2.VpcProps(**vpc_props)
+            vpc_props = _aws_cdk_aws_ec2_ceddda9d.VpcProps(**vpc_props)
         if __debug__:
-            def stub(
-                *,
-                public_api: builtins.bool,
-                cluster_props: typing.Optional[typing.Union[aws_cdk.aws_ecs.ClusterProps, typing.Dict[str, typing.Any]]] = None,
-                container_definition_props: typing.Any = None,
-                dead_letter_queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
-                ecr_image_version: typing.Optional[builtins.str] = None,
-                ecr_repository_arn: typing.Optional[builtins.str] = None,
-                enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
-                encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
-                encryption_key_props: typing.Optional[typing.Union[aws_cdk.aws_kms.KeyProps, typing.Dict[str, typing.Any]]] = None,
-                existing_container_definition_object: typing.Optional[aws_cdk.aws_ecs.ContainerDefinition] = None,
-                existing_fargate_service_object: typing.Optional[aws_cdk.aws_ecs.FargateService] = None,
-                existing_queue_obj: typing.Optional[aws_cdk.aws_sqs.Queue] = None,
-                existing_vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
-                fargate_service_props: typing.Any = None,
-                fargate_task_definition_props: typing.Any = None,
-                max_receive_count: typing.Optional[jsii.Number] = None,
-                queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
-                queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
-                queue_props: typing.Optional[typing.Union[aws_cdk.aws_sqs.QueueProps, typing.Dict[str, typing.Any]]] = None,
-                queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
-                vpc_props: typing.Optional[typing.Union[aws_cdk.aws_ec2.VpcProps, typing.Dict[str, typing.Any]]] = None,
-            ) -> None:
-                ...
-            type_hints = typing.get_type_hints(stub)
+            type_hints = typing.get_type_hints(_typecheckingstub__525fc17f18c1bcd553c2ec41ca803ba8da9f8e1fc4540578ed7f4ec4ed6194a5)
             check_type(argname="argument public_api", value=public_api, expected_type=type_hints["public_api"])
             check_type(argname="argument cluster_props", value=cluster_props, expected_type=type_hints["cluster_props"])
             check_type(argname="argument container_definition_props", value=container_definition_props, expected_type=type_hints["container_definition_props"])
@@ -446,7 +394,7 @@ class FargateToSqsProps:
             check_type(argname="argument queue_props", value=queue_props, expected_type=type_hints["queue_props"])
             check_type(argname="argument queue_url_environment_variable_name", value=queue_url_environment_variable_name, expected_type=type_hints["queue_url_environment_variable_name"])
             check_type(argname="argument vpc_props", value=vpc_props, expected_type=type_hints["vpc_props"])
-        self._values: typing.Dict[str, typing.Any] = {
+        self._values: typing.Dict[builtins.str, typing.Any] = {
             "public_api": public_api,
         }
         if cluster_props is not None:
@@ -498,18 +446,16 @@ class FargateToSqsProps:
 
         This has implications for the VPC deployed
         by this construct.
-
-        :default: - none
         '''
         result = self._values.get("public_api")
         assert result is not None, "Required property 'public_api' is missing"
         return typing.cast(builtins.bool, result)
 
     @builtins.property
-    def cluster_props(self) -> typing.Optional[aws_cdk.aws_ecs.ClusterProps]:
+    def cluster_props(self) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps]:
         '''Optional properties to create a new ECS cluster.'''
         result = self._values.get("cluster_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ClusterProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ClusterProps], result)
 
     @builtins.property
     def container_definition_props(self) -> typing.Any:
@@ -517,13 +463,15 @@ class FargateToSqsProps:
         return typing.cast(typing.Any, result)
 
     @builtins.property
-    def dead_letter_queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def dead_letter_queue_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user provided properties for the dead letter queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("dead_letter_queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def deploy_dead_letter_queue(self) -> typing.Optional[builtins.bool]:
@@ -567,34 +515,36 @@ class FargateToSqsProps:
         return typing.cast(typing.Optional[builtins.bool], result)
 
     @builtins.property
-    def encryption_key(self) -> typing.Optional[aws_cdk.aws_kms.Key]:
+    def encryption_key(self) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key]:
         '''An optional, imported encryption key to encrypt the SQS Queue with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.Key], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key], result)
 
     @builtins.property
-    def encryption_key_props(self) -> typing.Optional[aws_cdk.aws_kms.KeyProps]:
+    def encryption_key_props(
+        self,
+    ) -> typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps]:
         '''Optional user provided properties to override the default properties for the KMS encryption key used to encrypt the SQS Queue with.
 
         :default: - None
         '''
         result = self._values.get("encryption_key_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_kms.KeyProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_kms_ceddda9d.KeyProps], result)
 
     @builtins.property
     def existing_container_definition_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.ContainerDefinition]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition]:
         result = self._values.get("existing_container_definition_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.ContainerDefinition], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition], result)
 
     @builtins.property
     def existing_fargate_service_object(
         self,
-    ) -> typing.Optional[aws_cdk.aws_ecs.FargateService]:
+    ) -> typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService]:
         '''A Fargate Service already instantiated (probably by another Solutions Construct).
 
         If
@@ -606,19 +556,19 @@ class FargateToSqsProps:
         :default: - none
         '''
         result = self._values.get("existing_fargate_service_object")
-        return typing.cast(typing.Optional[aws_cdk.aws_ecs.FargateService], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService], result)
 
     @builtins.property
-    def existing_queue_obj(self) -> typing.Optional[aws_cdk.aws_sqs.Queue]:
+    def existing_queue_obj(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue]:
         '''Existing instance of SQS queue object, Providing both this and queueProps will cause an error.
 
         :default: - Default props are used
         '''
         result = self._values.get("existing_queue_obj")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.Queue], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue], result)
 
     @builtins.property
-    def existing_vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+    def existing_vpc(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc]:
         '''An existing VPC in which to deploy the construct.
 
         Providing both this and
@@ -629,7 +579,7 @@ class FargateToSqsProps:
         :default: - none
         '''
         result = self._values.get("existing_vpc")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc], result)
 
     @builtins.property
     def fargate_service_props(self) -> typing.Any:
@@ -675,13 +625,13 @@ class FargateToSqsProps:
         return typing.cast(typing.Optional[typing.List[builtins.str]], result)
 
     @builtins.property
-    def queue_props(self) -> typing.Optional[aws_cdk.aws_sqs.QueueProps]:
+    def queue_props(self) -> typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps]:
         '''Optional user-provided props to override the default props for the SQS queue.
 
         :default: - Default props are used
         '''
         result = self._values.get("queue_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_sqs.QueueProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_sqs_ceddda9d.QueueProps], result)
 
     @builtins.property
     def queue_url_environment_variable_name(self) -> typing.Optional[builtins.str]:
@@ -693,7 +643,7 @@ class FargateToSqsProps:
         return typing.cast(typing.Optional[builtins.str], result)
 
     @builtins.property
-    def vpc_props(self) -> typing.Optional[aws_cdk.aws_ec2.VpcProps]:
+    def vpc_props(self) -> typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps]:
         '''Optional custom properties for a VPC the construct will create.
 
         This VPC will
@@ -705,7 +655,7 @@ class FargateToSqsProps:
         :default: - none
         '''
         result = self._values.get("vpc_props")
-        return typing.cast(typing.Optional[aws_cdk.aws_ec2.VpcProps], result)
+        return typing.cast(typing.Optional[_aws_cdk_aws_ec2_ceddda9d.VpcProps], result)
 
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
@@ -725,3 +675,61 @@ __all__ = [
 ]
 
 publication.publish()
+
+def _typecheckingstub__1ba793faae145910b2917cda14247795539c6dff02cf4650e68799b90571b95f(
+    scope: _constructs_77d1e7e8.Construct,
+    id: builtins.str,
+    *,
+    public_api: builtins.bool,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
+    queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
+
+def _typecheckingstub__525fc17f18c1bcd553c2ec41ca803ba8da9f8e1fc4540578ed7f4ec4ed6194a5(
+    *,
+    public_api: builtins.bool,
+    cluster_props: typing.Optional[typing.Union[_aws_cdk_aws_ecs_ceddda9d.ClusterProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    container_definition_props: typing.Any = None,
+    dead_letter_queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    deploy_dead_letter_queue: typing.Optional[builtins.bool] = None,
+    ecr_image_version: typing.Optional[builtins.str] = None,
+    ecr_repository_arn: typing.Optional[builtins.str] = None,
+    enable_encryption_with_customer_managed_key: typing.Optional[builtins.bool] = None,
+    encryption_key: typing.Optional[_aws_cdk_aws_kms_ceddda9d.Key] = None,
+    encryption_key_props: typing.Optional[typing.Union[_aws_cdk_aws_kms_ceddda9d.KeyProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    existing_container_definition_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.ContainerDefinition] = None,
+    existing_fargate_service_object: typing.Optional[_aws_cdk_aws_ecs_ceddda9d.FargateService] = None,
+    existing_queue_obj: typing.Optional[_aws_cdk_aws_sqs_ceddda9d.Queue] = None,
+    existing_vpc: typing.Optional[_aws_cdk_aws_ec2_ceddda9d.IVpc] = None,
+    fargate_service_props: typing.Any = None,
+    fargate_task_definition_props: typing.Any = None,
+    max_receive_count: typing.Optional[jsii.Number] = None,
+    queue_arn_environment_variable_name: typing.Optional[builtins.str] = None,
+    queue_permissions: typing.Optional[typing.Sequence[builtins.str]] = None,
+    queue_props: typing.Optional[typing.Union[_aws_cdk_aws_sqs_ceddda9d.QueueProps, typing.Dict[builtins.str, typing.Any]]] = None,
+    queue_url_environment_variable_name: typing.Optional[builtins.str] = None,
+    vpc_props: typing.Optional[typing.Union[_aws_cdk_aws_ec2_ceddda9d.VpcProps, typing.Dict[builtins.str, typing.Any]]] = None,
+) -> None:
+    """Type checking stubs"""
+    pass
